Documentation
¶
Overview ¶
Package propertycanlike contains the implementation for the canLike property. All applications are strongly encouraged to use the interface instead of this concrete definition. The interfaces allow applications to consume only the types and properties needed and be independent of the go-fed implementation if another alternative implementation is created. This package is code-generated and subject to the same license as the go-fed tool used to generate it.
This package is independent of other types' and properties' implementations by having a Manager injected into it to act as a factory for the concrete implementations. The implementations have been generated into their own separate subpackages for each vocabulary.
Strongly consider using the interfaces instead of this package.
Index ¶
- func DeserializeCanLikeProperty(m map[string]interface{}, aliasMap map[string]string) (vocab.GoToSocialCanLikeProperty, error)
- func SetManager(m privateManager)
- type GoToSocialCanLikeProperty
- func (this *GoToSocialCanLikeProperty) AppendGoToSocialCanLike(v vocab.GoToSocialCanLike)
- func (this *GoToSocialCanLikeProperty) AppendIRI(v *url.URL)
- func (this *GoToSocialCanLikeProperty) AppendType(t vocab.Type) error
- func (this GoToSocialCanLikeProperty) At(index int) vocab.GoToSocialCanLikePropertyIterator
- func (this GoToSocialCanLikeProperty) Begin() vocab.GoToSocialCanLikePropertyIterator
- func (this GoToSocialCanLikeProperty) Empty() bool
- func (this GoToSocialCanLikeProperty) End() vocab.GoToSocialCanLikePropertyIterator
- func (this *GoToSocialCanLikeProperty) InsertGoToSocialCanLike(idx int, v vocab.GoToSocialCanLike)
- func (this *GoToSocialCanLikeProperty) InsertIRI(idx int, v *url.URL)
- func (this *GoToSocialCanLikeProperty) InsertType(idx int, t vocab.Type) error
- func (this GoToSocialCanLikeProperty) JSONLDContext() map[string]string
- func (this GoToSocialCanLikeProperty) KindIndex(idx int) int
- func (this GoToSocialCanLikeProperty) Len() (length int)
- func (this GoToSocialCanLikeProperty) Less(i, j int) bool
- func (this GoToSocialCanLikeProperty) LessThan(o vocab.GoToSocialCanLikeProperty) bool
- func (this GoToSocialCanLikeProperty) Name() string
- func (this *GoToSocialCanLikeProperty) PrependGoToSocialCanLike(v vocab.GoToSocialCanLike)
- func (this *GoToSocialCanLikeProperty) PrependIRI(v *url.URL)
- func (this *GoToSocialCanLikeProperty) PrependType(t vocab.Type) error
- func (this *GoToSocialCanLikeProperty) Remove(idx int)
- func (this GoToSocialCanLikeProperty) Serialize() (interface{}, error)
- func (this *GoToSocialCanLikeProperty) Set(idx int, v vocab.GoToSocialCanLike)
- func (this *GoToSocialCanLikeProperty) SetIRI(idx int, v *url.URL)
- func (this *GoToSocialCanLikeProperty) SetType(idx int, t vocab.Type) error
- func (this GoToSocialCanLikeProperty) Swap(i, j int)
- type GoToSocialCanLikePropertyIterator
- func (this GoToSocialCanLikePropertyIterator) Get() vocab.GoToSocialCanLike
- func (this GoToSocialCanLikePropertyIterator) GetIRI() *url.URL
- func (this GoToSocialCanLikePropertyIterator) GetType() vocab.Type
- func (this GoToSocialCanLikePropertyIterator) HasAny() bool
- func (this GoToSocialCanLikePropertyIterator) IsGoToSocialCanLike() bool
- func (this GoToSocialCanLikePropertyIterator) IsIRI() bool
- func (this GoToSocialCanLikePropertyIterator) JSONLDContext() map[string]string
- func (this GoToSocialCanLikePropertyIterator) KindIndex() int
- func (this GoToSocialCanLikePropertyIterator) LessThan(o vocab.GoToSocialCanLikePropertyIterator) bool
- func (this GoToSocialCanLikePropertyIterator) Name() string
- func (this GoToSocialCanLikePropertyIterator) Next() vocab.GoToSocialCanLikePropertyIterator
- func (this GoToSocialCanLikePropertyIterator) Prev() vocab.GoToSocialCanLikePropertyIterator
- func (this *GoToSocialCanLikePropertyIterator) Set(v vocab.GoToSocialCanLike)
- func (this *GoToSocialCanLikePropertyIterator) SetIRI(v *url.URL)
- func (this *GoToSocialCanLikePropertyIterator) SetType(t vocab.Type) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeserializeCanLikeProperty ¶
func DeserializeCanLikeProperty(m map[string]interface{}, aliasMap map[string]string) (vocab.GoToSocialCanLikeProperty, error)
DeserializeCanLikeProperty creates a "canLike" property from an interface representation that has been unmarshalled from a text or binary format.
func SetManager ¶
func SetManager(m privateManager)
SetManager sets the manager package-global variable. For internal use only, do not use as part of Application behavior. Must be called at golang init time.
Types ¶
type GoToSocialCanLikeProperty ¶
type GoToSocialCanLikeProperty struct {
// contains filtered or unexported fields
}
GoToSocialCanLikeProperty is the non-functional property "canLike". It is permitted to have one or more values, and of different value types.
func NewGoToSocialCanLikeProperty ¶
func NewGoToSocialCanLikeProperty() *GoToSocialCanLikeProperty
NewGoToSocialCanLikeProperty creates a new canLike property.
func (*GoToSocialCanLikeProperty) AppendGoToSocialCanLike ¶
func (this *GoToSocialCanLikeProperty) AppendGoToSocialCanLike(v vocab.GoToSocialCanLike)
AppendGoToSocialCanLike appends a CanLike value to the back of a list of the property "canLike". Invalidates iterators that are traversing using Prev.
func (*GoToSocialCanLikeProperty) AppendIRI ¶
func (this *GoToSocialCanLikeProperty) AppendIRI(v *url.URL)
AppendIRI appends an IRI value to the back of a list of the property "canLike"
func (*GoToSocialCanLikeProperty) AppendType ¶
func (this *GoToSocialCanLikeProperty) AppendType(t vocab.Type) error
PrependType prepends an arbitrary type value to the front of a list of the property "canLike". Invalidates iterators that are traversing using Prev. Returns an error if the type is not a valid one to set for this property.
func (GoToSocialCanLikeProperty) At ¶
func (this GoToSocialCanLikeProperty) At(index int) vocab.GoToSocialCanLikePropertyIterator
At returns the property value for the specified index. Panics if the index is out of bounds.
func (GoToSocialCanLikeProperty) Begin ¶
func (this GoToSocialCanLikeProperty) Begin() vocab.GoToSocialCanLikePropertyIterator
Begin returns the first iterator, or nil if empty. Can be used with the iterator's Next method and this property's End method to iterate from front to back through all values.
func (GoToSocialCanLikeProperty) Empty ¶
func (this GoToSocialCanLikeProperty) Empty() bool
Empty returns returns true if there are no elements.
func (GoToSocialCanLikeProperty) End ¶
func (this GoToSocialCanLikeProperty) End() vocab.GoToSocialCanLikePropertyIterator
End returns beyond-the-last iterator, which is nil. Can be used with the iterator's Next method and this property's Begin method to iterate from front to back through all values.
func (*GoToSocialCanLikeProperty) InsertGoToSocialCanLike ¶
func (this *GoToSocialCanLikeProperty) InsertGoToSocialCanLike(idx int, v vocab.GoToSocialCanLike)
InsertGoToSocialCanLike inserts a CanLike value at the specified index for a property "canLike". Existing elements at that index and higher are shifted back once. Invalidates all iterators.
func (*GoToSocialCanLikeProperty) InsertIRI ¶
func (this *GoToSocialCanLikeProperty) InsertIRI(idx int, v *url.URL)
Insert inserts an IRI value at the specified index for a property "canLike". Existing elements at that index and higher are shifted back once. Invalidates all iterators.
func (*GoToSocialCanLikeProperty) InsertType ¶
func (this *GoToSocialCanLikeProperty) InsertType(idx int, t vocab.Type) error
PrependType prepends an arbitrary type value to the front of a list of the property "canLike". Invalidates all iterators. Returns an error if the type is not a valid one to set for this property.
func (GoToSocialCanLikeProperty) JSONLDContext ¶
func (this GoToSocialCanLikeProperty) JSONLDContext() map[string]string
JSONLDContext returns the JSONLD URIs required in the context string for this property and the specific values that are set. The value in the map is the alias used to import the property's value or values.
func (GoToSocialCanLikeProperty) KindIndex ¶
func (this GoToSocialCanLikeProperty) KindIndex(idx int) int
KindIndex computes an arbitrary value for indexing this kind of value. This is a leaky API method specifically needed only for alternate implementations for go-fed. Applications should not use this method. Panics if the index is out of bounds.
func (GoToSocialCanLikeProperty) Len ¶
func (this GoToSocialCanLikeProperty) Len() (length int)
Len returns the number of values that exist for the "canLike" property.
func (GoToSocialCanLikeProperty) Less ¶
func (this GoToSocialCanLikeProperty) Less(i, j int) bool
Less computes whether another property is less than this one. Mixing types results in a consistent but arbitrary ordering
func (GoToSocialCanLikeProperty) LessThan ¶
func (this GoToSocialCanLikeProperty) LessThan(o vocab.GoToSocialCanLikeProperty) bool
LessThan compares two instances of this property with an arbitrary but stable comparison. Applications should not use this because it is only meant to help alternative implementations to go-fed to be able to normalize nonfunctional properties.
func (GoToSocialCanLikeProperty) Name ¶
func (this GoToSocialCanLikeProperty) Name() string
Name returns the name of this property ("canLike") with any alias.
func (*GoToSocialCanLikeProperty) PrependGoToSocialCanLike ¶
func (this *GoToSocialCanLikeProperty) PrependGoToSocialCanLike(v vocab.GoToSocialCanLike)
PrependGoToSocialCanLike prepends a CanLike value to the front of a list of the property "canLike". Invalidates all iterators.
func (*GoToSocialCanLikeProperty) PrependIRI ¶
func (this *GoToSocialCanLikeProperty) PrependIRI(v *url.URL)
PrependIRI prepends an IRI value to the front of a list of the property "canLike".
func (*GoToSocialCanLikeProperty) PrependType ¶
func (this *GoToSocialCanLikeProperty) PrependType(t vocab.Type) error
PrependType prepends an arbitrary type value to the front of a list of the property "canLike". Invalidates all iterators. Returns an error if the type is not a valid one to set for this property.
func (*GoToSocialCanLikeProperty) Remove ¶
func (this *GoToSocialCanLikeProperty) Remove(idx int)
Remove deletes an element at the specified index from a list of the property "canLike", regardless of its type. Panics if the index is out of bounds. Invalidates all iterators.
func (GoToSocialCanLikeProperty) Serialize ¶
func (this GoToSocialCanLikeProperty) Serialize() (interface{}, error)
Serialize converts this into an interface representation suitable for marshalling into a text or binary format. Applications should not need this function as most typical use cases serialize types instead of individual properties. It is exposed for alternatives to go-fed implementations to use.
func (*GoToSocialCanLikeProperty) Set ¶
func (this *GoToSocialCanLikeProperty) Set(idx int, v vocab.GoToSocialCanLike)
Set sets a CanLike value to be at the specified index for the property "canLike". Panics if the index is out of bounds. Invalidates all iterators.
func (*GoToSocialCanLikeProperty) SetIRI ¶
func (this *GoToSocialCanLikeProperty) SetIRI(idx int, v *url.URL)
SetIRI sets an IRI value to be at the specified index for the property "canLike". Panics if the index is out of bounds.
func (*GoToSocialCanLikeProperty) SetType ¶
func (this *GoToSocialCanLikeProperty) SetType(idx int, t vocab.Type) error
SetType sets an arbitrary type value to the specified index of the property "canLike". Invalidates all iterators. Returns an error if the type is not a valid one to set for this property. Panics if the index is out of bounds.
func (GoToSocialCanLikeProperty) Swap ¶
func (this GoToSocialCanLikeProperty) Swap(i, j int)
Swap swaps the location of values at two indices for the "canLike" property.
type GoToSocialCanLikePropertyIterator ¶
type GoToSocialCanLikePropertyIterator struct {
// contains filtered or unexported fields
}
GoToSocialCanLikePropertyIterator is an iterator for a property. It is permitted to be a single nilable value type.
func NewGoToSocialCanLikePropertyIterator ¶
func NewGoToSocialCanLikePropertyIterator() *GoToSocialCanLikePropertyIterator
NewGoToSocialCanLikePropertyIterator creates a new GoToSocialCanLike property.
func (GoToSocialCanLikePropertyIterator) Get ¶
func (this GoToSocialCanLikePropertyIterator) Get() vocab.GoToSocialCanLike
Get returns the value of this property. When IsGoToSocialCanLike returns false, Get will return any arbitrary value.
func (GoToSocialCanLikePropertyIterator) GetIRI ¶
func (this GoToSocialCanLikePropertyIterator) GetIRI() *url.URL
GetIRI returns the IRI of this property. When IsIRI returns false, GetIRI will return any arbitrary value.
func (GoToSocialCanLikePropertyIterator) GetType ¶
func (this GoToSocialCanLikePropertyIterator) GetType() vocab.Type
GetType returns the value in this property as a Type. Returns nil if the value is not an ActivityStreams type, such as an IRI or another value.
func (GoToSocialCanLikePropertyIterator) HasAny ¶
func (this GoToSocialCanLikePropertyIterator) HasAny() bool
HasAny returns true if the value or IRI is set.
func (GoToSocialCanLikePropertyIterator) IsGoToSocialCanLike ¶
func (this GoToSocialCanLikePropertyIterator) IsGoToSocialCanLike() bool
IsGoToSocialCanLike returns true if this property is set and not an IRI.
func (GoToSocialCanLikePropertyIterator) IsIRI ¶
func (this GoToSocialCanLikePropertyIterator) IsIRI() bool
IsIRI returns true if this property is an IRI.
func (GoToSocialCanLikePropertyIterator) JSONLDContext ¶
func (this GoToSocialCanLikePropertyIterator) JSONLDContext() map[string]string
JSONLDContext returns the JSONLD URIs required in the context string for this property and the specific values that are set. The value in the map is the alias used to import the property's value or values.
func (GoToSocialCanLikePropertyIterator) KindIndex ¶
func (this GoToSocialCanLikePropertyIterator) KindIndex() int
KindIndex computes an arbitrary value for indexing this kind of value. This is a leaky API detail only for folks looking to replace the go-fed implementation. Applications should not use this method.
func (GoToSocialCanLikePropertyIterator) LessThan ¶
func (this GoToSocialCanLikePropertyIterator) LessThan(o vocab.GoToSocialCanLikePropertyIterator) bool
LessThan compares two instances of this property with an arbitrary but stable comparison. Applications should not use this because it is only meant to help alternative implementations to go-fed to be able to normalize nonfunctional properties.
func (GoToSocialCanLikePropertyIterator) Name ¶
func (this GoToSocialCanLikePropertyIterator) Name() string
Name returns the name of this property: "GoToSocialCanLike".
func (GoToSocialCanLikePropertyIterator) Next ¶
func (this GoToSocialCanLikePropertyIterator) Next() vocab.GoToSocialCanLikePropertyIterator
Next returns the next iterator, or nil if there is no next iterator.
func (GoToSocialCanLikePropertyIterator) Prev ¶
func (this GoToSocialCanLikePropertyIterator) Prev() vocab.GoToSocialCanLikePropertyIterator
Prev returns the previous iterator, or nil if there is no previous iterator.
func (*GoToSocialCanLikePropertyIterator) Set ¶
func (this *GoToSocialCanLikePropertyIterator) Set(v vocab.GoToSocialCanLike)
Set sets the value of this property. Calling IsGoToSocialCanLike afterwards will return true.
func (*GoToSocialCanLikePropertyIterator) SetIRI ¶
func (this *GoToSocialCanLikePropertyIterator) SetIRI(v *url.URL)
SetIRI sets the value of this property. Calling IsIRI afterwards will return true.